@@ -87,7 +87,6 @@ diagnose <- function(.data, ...) {
 #' @method diagnose data.frame
 #' @importFrom tidyselect vars_select
 #' @importFrom rlang quos
-#' @importFrom methods is
 #' @export
 diagnose.data.frame <- function(.data, ...) {
   vars <- tidyselect::vars_select(names(.data), !!! rlang::quos(...))
@@ -95,6 +94,7 @@ diagnose.data.frame <- function(.data, ...) {
 }
 
 #' @import tibble
+#' @importFrom methods is
 #' @importFrom stats complete.cases
 diagn_std_impl <- function(df, vars) {
   if (length(vars) == 0) vars <- names(df)
@@ -549,8 +549,9 @@ plot_outlier <- function(.data, ...) {
 #' These arguments are automatically quoted and evaluated in a context
 #' where column names represent column positions.
 #' They support unquoting and splicing.
-#' @param col a color to be used to fill the bars. The default is "lightblue".
-#'
+#' @param col a color to be used to fill the bars. The default is "steelblue".
+#' @param typographic logical. Whether to apply focuses on typographic elements to ggplot2 visualization. 
+#' The default is TRUE. if TRUE provides a base theme that focuses on typographic elements using hrbrthemes package.
 #' @seealso \code{\link{plot_outlier.tbl_dbi}}, \code{\link{diagnose_outlier.data.frame}}.
 #' @export
 #' @examples
@@ -560,32 +561,39 @@ plot_outlier <- function(.data, ...) {
 #' carseats[sample(seq(NROW(carseats)), 5), "Urban"] <- NA
 #'
 #' # Visualization of all numerical variables
-#' plot_outlier(carseats)
+#' # plot_outlier(carseats)
 #'
 #' # Select the variable to diagnose
 #' plot_outlier(carseats, Sales, Price)
-#' plot_outlier(carseats, -Sales, -Price)
-#' plot_outlier(carseats, "Sales", "Price")
-#' plot_outlier(carseats, 6)
+#' # plot_outlier(carseats, -Sales, -Price)
+#' # plot_outlier(carseats, "Sales", "Price")
+#' # plot_outlier(carseats, 6)
 #'
 #' # Using the col argument
-#' plot_outlier(carseats, Sales, col = "gray")
+#' # plot_outlier(carseats, Sales, col = "gray")
+#' 
+#' # Not allow typographic argument
+#' # plot_outlier(carseats, Sales, typographic = FALSE)
 #' 
 #' # Using pipes ---------------------------------
 #' library(dplyr)
 #'
 #' # Visualization of all numerical variables
-#' carseats %>%
-#'   plot_outlier()
+#' # carseats %>%
+#' #   plot_outlier()
+#'   
 #' # Positive values select variables
 #' carseats %>%
 #'   plot_outlier(Sales, Price)
+#'   
 #' # Negative values to drop variables
-#' carseats %>%
-#'   plot_outlier(-Sales, -Price)
+#' # carseats %>%
+#' #   plot_outlier(-Sales, -Price)
+#'   
 #' # Positions values select variables
-#' carseats %>%
-#'   plot_outlier(6)
+#' # carseats %>%
+#' #   plot_outlier(6)
+#'   
 #' # Positions values select variables
 #' carseats %>%
 #'   plot_outlier(-1, -5)
@@ -593,24 +601,24 @@ plot_outlier <- function(.data, ...) {
 #' # Using pipes & dplyr -------------------------
 #' # Visualization of numerical variables with a ratio of
 #' # outliers greater than 1%
-#' carseats %>%
-#'   plot_outlier(carseats %>%
-#'       diagnose_outlier() %>%
-#'       filter(outliers_ratio > 1) %>%
-#'       select(variables) %>%
-#'       pull())
+#' # carseats %>%
+#' #   plot_outlier(carseats %>%
+#' #      diagnose_outlier() %>%
+#' #      filter(outliers_ratio > 1) %>%
+#' #      select(variables) %>%
+#' #      pull())
 #'   
 #' @method plot_outlier data.frame
 #' @importFrom tidyselect vars_select
 #' @importFrom rlang quos
 #' @export
-plot_outlier.data.frame <- function(.data, ..., col = "lightblue") {
+plot_outlier.data.frame <- function(.data, ..., col = "steelblue", typographic = TRUE) {
   vars <- tidyselect::vars_select(names(.data), !!! rlang::quos(...))
-  plot_outlier_impl(.data, vars, col)
+  plot_outlier_impl(.data, vars, col, typographic)
 }
 
 #' @importFrom graphics boxplot hist title par
-plot_outlier_impl <- function(df, vars, col = "lightblue") {
+plot_outlier_impl <- function(df, vars, col = "steelblue", typographic = TRUE) {
   if (length(vars) == 0) vars <- names(df)
 
   if (length(vars) == 1 & !tibble::is_tibble(df)) 
@@ -618,22 +626,11 @@ plot_outlier_impl <- function(df, vars, col = "lightblue") {
 
   idx_numeric <- find_class(df[, vars], type = "numerical")
   
-  plot_outliers <- function(df, var, col) {
+  plot_outliers <- function(df, var, col, typographic) {
     x <- dplyr::pull(df, var)
+    main <- sprintf("Outlier Diagnosis Plot (%s)", var)
     
-    op <- par(no.readonly = TRUE)
-    par(mfrow = c(2, 2), oma = c(0, 0, 3, 0), mar = c(2, 4, 2, 2))
-    on.exit(par(op))
-
-    boxplot(x, main = "With outliers", col = col)
-    hist(x, main = "With outliers", xlab = NA, ylab = NA, col = col)
-
-    outlier <- boxplot.stats(x)$out
-    x <- ifelse(x %in% outlier, NA, x)
-    boxplot(x, main = "Without outliers", col = col)
-    hist(x, main = "Without outliers", xlab = NA, ylab = NA, col = col)
-
-    title(sprintf("Outlier Diagnosis Plot (%s)", var), outer = TRUE)
+    plot_outlier_raw(x, main, col, typographic)
   }
 
   if (length(idx_numeric) == 0) {
@@ -651,7 +648,280 @@ plot_outlier_impl <- function(df, vars, col = "lightblue") {
     }
     
     tmp <- lapply(vars[idx_numeric][!idx_na],
-                  function(x) plot_outliers(df, x, col))
+                  function(x) plot_outliers(df, x, col, typographic))
+  }
+}
+
+#' @import ggplot2
+#' @import hrbrthemes
+#' @importFrom gridExtra grid.arrange
+#' @importFrom grid textGrob gpar
+plot_outlier_raw <- function(x, main = NULL, col = "steelblue", typographic = TRUE) {
+  main <- ifelse(is.null(main), "Outlier Diagnose Plot", main)
+  
+  df_all <- data.frame(x = x) %>% 
+    filter(!is.na(x))
+  
+  df_out <- data.frame(x = x) %>% 
+    filter(!is.na(x)) %>% 
+    filter(!x  %in% boxplot.stats(x)$out)
+  
+  # calulate number of bins using Sturges' formula
+  n_bins_all <- round(log2(nrow(df_all)) + 1)
+  n_bins_out <- round(log2(nrow(df_out)) + 1)
+  
+  top_left <- df_all %>% 
+    ggplot(aes(x)) +
+    geom_boxplot(fill = col, color = "black", alpha = 0.8) +
+    coord_flip(ylim = c(-0.7, 0.7)) + 
+    labs(title = "With outliers", x = "", y = "") +
+    theme(axis.text.x = element_blank(),
+          axis.ticks.x = element_blank())
+  
+  bottom_left <- df_out %>% 
+    ggplot(aes(x)) +
+    geom_boxplot(fill = col, color = "black", alpha = 0.8) +
+    coord_flip(ylim = c(-0.7, 0.7)) + 
+    labs(title = "With outliers", x = "", y = "") +
+    theme(axis.text.x = element_blank(),
+          axis.ticks.x = element_blank())
+  
+  top_right <- df_all %>% 
+    ggplot(aes(x)) +
+    geom_histogram(fill = col, color = "black", alpha = 0.8, bins = n_bins_all) +
+    labs(title = "With outliers", x = "", y = "")
+  
+  bottom_right <- df_out %>% 
+    ggplot(aes(x)) +
+    geom_histogram(fill = col, color = "black", alpha = 0.8, bins = n_bins_out) +
+    labs(title = "Without outliers", x = "", y = "")
+  
+  if (typographic) {
+    top_left <- top_left +
+      theme_typographic() +
+      theme(axis.text.x = element_blank(),
+            axis.ticks.x = element_blank(),
+            plot.margin = margin(10, 30, 10, 30))
+    
+    top_right <- top_right +
+      theme_typographic() +
+      theme(plot.margin = margin(10, 30, 10, 30))
+    
+    bottom_left <- bottom_left +
+      theme_typographic() +
+      theme(axis.text.x = element_blank(),
+            axis.ticks.x = element_blank(),
+            plot.margin = margin(10, 30, 10, 30))
+    
+    bottom_right <- bottom_right +
+      theme_typographic() +
+      theme(plot.margin = margin(10, 30, 10, 30))    
+    
+    fontfamily <- get_font_family()
+    
+    top <- grid::textGrob(main, gp = grid::gpar(fontfamily = fontfamily, 
+                                                fontsize = 18, font = 2),
+                          x = unit(0.075, "npc"), just = "left")
+  } else {
+    top <- main
+  }
+  
+  suppressWarnings(gridExtra::grid.arrange(top_left, top_right, bottom_left, bottom_right, 
+                                           ncol = 2, nrow = 2, widths = c(2, 3), top = top))
+}
+
+
+#' Plot outlier information of target_df 
+#'
+#' @description The plot_outlier() visualize outlier information
+#' for diagnosing the quality of the numerical data with target_df class.
+#'
+#' @details The scope of the diagnosis is the provide a outlier information.
+#' Since the plot is drawn for each variable, if you specify more than
+#' one variable in the ... argument, the specified number of plots are drawn.
+#'
+#' @section Outlier diagnostic information:
+#' The plot derived from the numerical data diagnosis is as follows.
+#'
+#' \itemize{
+#' \item With outliers box plot by target variable
+#' \item Without outliers box plot by target variable
+#' \item With outliers density plot by target variable
+#' \item Without outliers density plot by target variable
+#' }
+#'
+#' @param .data a target_df. reference \code{\link{target_by}}.
+#' @param ... one or more unquoted expressions separated by commas.
+#' You can treat variable names like they are positions.
+#' Positive values select variables; negative values to drop variables.
+#' If the first expression is negative, plot_outlier() will automatically start
+#' with all variables.
+#' These arguments are automatically quoted and evaluated in a context
+#' where column names represent column positions.
+#' They support unquoting and splicing.
+#' @param typographic logical. Whether to apply focuses on typographic elements to ggplot2 visualization. 
+#' The default is TRUE. if TRUE provides a base theme that focuses on typographic elements using hrbrthemes package.
+#' @seealso \code{\link{plot_outlier.data.frame}}.
+#' @export
+#' @examples
+#' # Generate data for the example
+#' carseats <- ISLR::Carseats
+#' carseats[sample(seq(NROW(carseats)), 20), "Income"] <- NA
+#' carseats[sample(seq(NROW(carseats)), 5), "Urban"] <- NA
+#'
+#' # the target variable is a categorical variable
+#' categ <- target_by(carseats, US)
+#' 
+#' plot_outlier(categ, Price)
+#' plot_outlier(categ, Price, typographic = FALSE)
+#' 
+#' # using dplyr
+#' library(dplyr)
+#' carseats %>% 
+#'   target_by(US) %>% 
+#'   plot_outlier(Price, CompPrice)
+#' 
+#' # Using DBMS tables ----------------------------------
+#' # connect DBMS
+#' con_sqlite <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
+#' 
+#' # copy carseats to the DBMS with a table named TB_CARSEATS
+#' copy_to(con_sqlite, carseats, name = "TB_CARSEATS", overwrite = TRUE)
+#'
+#' # If the target variable is a categorical variable
+#' categ <- target_by(con_sqlite %>% tbl("TB_CARSEATS") , US)
+#' 
+#' plot_outlier(categ, Price)
+#' 
+#' @method plot_outlier target_df
+#' @importFrom tidyselect vars_select
+#' @importFrom rlang quos
+#' @export
+plot_outlier.target_df <- function(.data, ..., typographic = TRUE) {
+  vars <- tidyselect::vars_select(names(.data), !!! rlang::quos(...))
+  plot_outlier_target_impl(.data, vars, typographic)
+}
+
+#' @import dplyr
+#' @import ggplot2
+#' @importFrom tibble is_tibble
+#' @importFrom gridExtra grid.arrange
+plot_outlier_target_impl <- function(df, vars, typographic = TRUE) {
+  if (utils::packageVersion("dplyr") >= "0.8.0") {
+    target <- setdiff(attr(df, "groups") %>% names(), ".rows")
+  } else {
+    target <- attr(df, "vars")
+  }
+  
+  if (length(target) > 1) {
+    message(sprintf("plot_outlier() only supports one group variable. \
+                   However, the call now has %d group variables.", length(target)))
+    invisible(NULL)
+  }
+  
+  if (utils::packageVersion("dplyr") >= "0.8.0") {
+    type_target <- df[, target] %>% pull %>% is %>% "["(1)
+  } else {
+    type_target <- is(df[, target])[1]
+  } 
+  
+  if (!type_target %in% c("ordered", "factor", "character")) {
+    message("target variabe is not in  (\"ordered\", \"factor\", \"character\")")
+    invisible(NULL)
+  }
+  
+  if (length(vars) == 0) {
+    vars <- names(df)
+  }
+  
+  vars <- setdiff(vars, target)
+  
+  if (length(vars) == 0) {
+    message("There is no variable in variable list or target and variable are the same.\n")
+    invisible(NULL)
+  }
+  
+  plot_outliers <- function(df, target, predictor, typographic = TRUE) {
+    data_with <- df %>% 
+      ungroup() %>% 
+      select(all_of(target), all_of(predictor)) %>% 
+      filter(!is.na(target))
+    
+    box_with <- ggplot(data_with, aes_string(x = target, y = predictor, fill = target)) +
+      geom_boxplot(alpha = 0.8) +
+      labs(title = "boxplot with outliers") +
+      theme(legend.position = "none")
+    
+    density_with <- ggplot(data_with, aes_string(x = predictor, colour = target)) +
+      geom_density() +
+      labs(title = "density with outliers") 
+    
+    flag <- !data_with[, predictor] %>% pull %in% boxplot.stats(data_with[, predictor] %>% pull)$out
+    data_without <- data_with[flag, ]
+    
+    box_without <- ggplot(data_without, aes_string(x = target, y = predictor, fill = target)) +
+      geom_boxplot(alpha = 0.8) +
+      labs(title = "boxplot without outliers") +
+      theme(legend.position = "none")
+    
+    density_without <- ggplot(data_without, aes_string(x = predictor, colour = target)) +
+      geom_density() +
+      labs(title = "density with outliers") 
+    
+    if (typographic) {
+      box_with <- box_with +
+        theme_typographic() +
+        scale_fill_ipsum() + 
+        theme(legend.position = "none",
+              axis.title.x = element_text(size = 12),
+              axis.title.y = element_text(size = 12),
+              plot.margin = margin(10, 30, 10, 10))
+      
+      density_with <- density_with +
+        theme_typographic() +
+        scale_color_ipsum() +
+        theme(axis.title.x = element_text(size = 12),
+              axis.title.y = element_text(size = 12),
+              plot.margin = margin(10, 30, 10, 10))
+      
+      box_without <- box_without +
+        theme_typographic() +
+        scale_fill_ipsum() + 
+        theme(legend.position = "none",
+              axis.title.x = element_text(size = 12),
+              axis.title.y = element_text(size = 12),
+              plot.margin = margin(10, 30, 10, 10))
+      
+      density_without <- density_without +
+        theme_typographic() +
+        scale_color_ipsum() +
+        theme(axis.title.x = element_text(size = 12),
+              axis.title.y = element_text(size = 12),
+              plot.margin = margin(10, 30, 10, 10))    
+    }
+    
+    suppressWarnings(gridExtra::grid.arrange(box_with, density_with, box_without, density_without, 
+                                             nrow = 2, ncol = 2))
+  }
+  
+  idx_numeric <- find_class(df[, vars], type = "numerical")
+  
+  if (length(idx_numeric) == 0) {
+    message("There is no numeric variable in the data or variable list.\n")
+    invisible(NULL)
+  } else if (length(idx_numeric) == 1 & all(is.na(df[, vars]))) {
+    message("All observed values for numeric variables are NA.\n")
+    invisible(NULL)
+  } else {
+    idx_na <- sapply(vars[idx_numeric],
+                     function(x) all(is.na(df[, x])))
+    if (sum(idx_na) > 0) {
+      name_null <- paste(vars[idx_numeric][idx_na], collapse = ",")
+      message(sprintf("All observations for the numerical variable %s are NA.", name_null))
+    }
+    
+    tmp <- lapply(vars[idx_numeric][!idx_na],
+                  function(x) plot_outliers(df, target, x, typographic))
   }
 }
 
@@ -718,7 +988,7 @@ diagnose_report <- function(.data, output_format, output_file, output_dir, ...)
 #' @param ... arguments to be passed to methods.
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' carseats <- ISLR::Carseats
 #' carseats[sample(seq(NROW(carseats)), 20), "Income"] <- NA
 #' carseats[sample(seq(NROW(carseats)), 5), "Urban"] <- NA
@@ -730,7 +1000,7 @@ diagnose_report <- function(.data, output_format, output_file, output_dir, ...)
 #' diagnose_report(carseats, output_file = "Diagn.pdf")
 #' # create pdf file. file name is ./Diagn.pdf and not browse
 #' # diagnose_report(carseats, output_dir = ".", output_file = "Diagn.pdf", 
-#'   browse = FALSE)
+#' #   browse = FALSE)
 #' # create html file. file name is Diagnosis_Report.html
 #' diagnose_report(carseats, output_format = "html")
 #' # create html file. file name is Diagn.html
@@ -741,7 +1011,6 @@ diagnose_report <- function(.data, output_format, output_file, output_dir, ...)
 #' @importFrom rmarkdown render
 #' @importFrom prettydoc html_pretty
 #' @importFrom kableExtra kable_styling
-#' @importFrom tinytex latexmk
 #' @importFrom utils browseURL
 #' @method diagnose_report data.frame
 #' @export
@@ -827,4 +1096,4 @@ diagnose_report.data.frame <- function(.data, output_format = c("pdf", "html"),
   if (browse & file.exists(paste(path, output_file, sep = "/"))) {
     browseURL(paste(path, output_file, sep = "/"))
   }
-}
+}
\ No newline at end of file
