@@ -12,6 +12,8 @@
 #' @param main character. Main title.
 #' @param col.left character. The color of left legend that is frequency of NA. default is "#009E73".
 #' @param col.right character. The color of right legend that is percentage of NA. default is "#56B4E9".
+#' @param typographic logical. Whether to apply focuses on typographic elements to ggplot2 visualization. 
+#' The default is TRUE. if TRUE provides a base theme that focuses on typographic elements using hrbrthemes package.
 #' @examples
 #' # Generate data for the example
 #' carseats <- ISLR::Carseats
@@ -22,19 +24,26 @@
 #' plot_na_hclust(carseats)
 #' plot_na_hclust(airquality)
 #'   
-#' 
 #' # Visualize pareto chart for variables with missing value.
+#' if (!requireNamespace("mice", quietly = TRUE)) {
+#'   stop("Package \"mice\" needed for this function to work. Please install it.",
+#'   call. = FALSE)
+#' }
+#' 
 #' plot_na_hclust(mice::boys)
 #' 
 #' # Change the main title.
 #' plot_na_hclust(mice::boys, main = "Distribution of missing value")
 #' 
+#' # Not support typographic elements
+#' plot_na_hclust(mice::boys, typographic = FALSE)
+#' 
 #' @importFrom stats hclust dist order.dendrogram as.dendrogram reorder
-#' @importFrom reshape2 melt
 #' @import ggplot2
+#' @import hrbrthemes
 #' @export
 #' 
-plot_na_hclust <- function (x, main = NULL, col.left = "#009E73", col.right = "#56B4E9")
+plot_na_hclust <- function (x, main = NULL, col.left = "#009E73", col.right = "#56B4E9", typographic = TRUE)
 {
   N <- nrow(x)
   
@@ -47,7 +56,7 @@ plot_na_hclust <- function (x, main = NULL, col.left = "#009E73", col.right = "#
   na_variable <- names(na_variable[na_variable == TRUE])
   
   x <- x[na_obs, ] %>% 
-    select_at(vars(na_variable)) %>% 
+    select_at(all_of(na_variable)) %>% 
     is.na() %>% 
     as.matrix() + 0
   
@@ -84,27 +93,37 @@ plot_na_hclust <- function (x, main = NULL, col.left = "#009E73", col.right = "#
                            na_cnt = na_cnt,
                            na_pct = paste0(round(na_cnt / N * 100, 1), "%"))
   
-  dframe <- reshape2::melt(t(x))
+  dframe <- get_melt(x)
   dframe <- dframe[dframe$value != 0, ]
   
   if (is.null(main)) 
     main = "Distribution of missing value by combination of variables"
   
-  ggplot(dframe, aes(x = Var2, y = Var1)) + 
+  p <- ggplot(dframe, aes(x = Var2, y = Var1)) + 
     geom_raster(aes(fill = value)) + 
-    scale_fill_gradient(low = "grey", high = "red") +
+    scale_fill_gradient(low = "grey", high = "#d18975") +
     geom_label(data = label_info, aes(x = 0, y = pos_y, label = na_cnt), 
                hjust = 1, fill = col.left, size = 3, colour = "white", 
                fontface = "bold") +
     geom_label(data = label_info, aes(x = nr + 2, y = pos_y, label = na_pct), 
                hjust = 0, fill = col.right, size = 3, colour = "white", 
                fontface = "bold") +
-    labs(y = "Variables containing missing values", 
-         x = "Observations", title = main) +
+    labs(y = "Variables with missing values", 
+         x = "Number of observations", title = main) +
     theme(axis.text.x = element_text(size = 9, angle = 0, vjust = 0.3),
           axis.text.y = element_text(size = 10),
           plot.title = element_text(size = 11),
           legend.position = "none")
+  
+  if (typographic) {
+    p <- p +
+      theme_typographic() +
+      theme(legend.position = "none",
+            axis.title.x = element_text(size = 12),
+            axis.title.y = element_text(size = 12))
+  }
+  
+  suppressWarnings(p)
 }
 
 
@@ -124,6 +143,8 @@ plot_na_hclust <- function (x, main = NULL, col.left = "#009E73", col.right = "#
 #' @param main character. Main title.
 #' @param col character. The color of line for display the cumulative percentage.
 #' @param plot logical. If this value is TRUE then visualize plot. else if FALSE, return aggregate information about missing values.
+#' @param typographic logical. Whether to apply focuses on typographic elements to ggplot2 visualization. 
+#' The default is TRUE. if TRUE provides a base theme that focuses on typographic elements using hrbrthemes package.
 #' @examples
 #' # Generate data for the example
 #' carseats <- ISLR::Carseats
@@ -141,12 +162,17 @@ plot_na_hclust <- function (x, main = NULL, col.left = "#009E73", col.right = "#
 #' plot_na_pareto(airquality)
 #'   
 #' # Diagnose the data with missing_count using diagnose() function
+#' if (!requireNamespace("mice", quietly = TRUE)) {
+#'   stop("Package \"mice\" needed for this function to work. Please install it.",
+#'   call. = FALSE)
+#' }
+#' 
 #' mice::boys %>% 
 #'   diagnose %>% 
 #'   arrange(desc(missing_count))
 #' 
 #' # Visualize pareto chart for variables with missing value.
-#' plot_na_pareto(mice::boys, col = "darkorange")
+#' plot_na_pareto(mice::boys, col = "blue")
 #' 
 #' # Visualize only variables containing missing values
 #' plot_na_pareto(mice::boys, only_na = TRUE)
@@ -164,15 +190,17 @@ plot_na_hclust <- function (x, main = NULL, col.left = "#009E73", col.right = "#
 #' # Return the aggregate information about missing values.
 #' plot_na_pareto(mice::boys, only_na = TRUE, plot = FALSE)
 #' 
+#' # Not support typographic elements
+#' plot_na_pareto(mice::boys, typographic = FALSE)
+#' 
 #' @importFrom purrr map_int
 #' @importFrom tibble enframe
 #' @importFrom dplyr rename
-#' @importFrom forcats fct_reorder
 #' @import ggplot2
 #' @export
 plot_na_pareto <- function (x, only_na = FALSE, relative = FALSE, main = NULL, col = "black",
                             grade = list(Good = 0.05, OK = 0.4, Bad = 0.8, Remove = 1),
-                            plot = TRUE)
+                            plot = TRUE, typographic = TRUE)
 {
   if (sum(is.na(x)) == 0) {
     stop("Data have no missing value.")
@@ -185,7 +213,9 @@ plot_na_pareto <- function (x, only_na = FALSE, relative = FALSE, main = NULL, c
     mutate(ratio = frequencies / nrow(x)) %>% 
     mutate(grade = cut(ratio, breaks = c(-1, unlist(grade)), labels = names(grade))) %>% 
     mutate(cumulative = cumsum(frequencies) / sum(frequencies) * 100) %>% 
-    mutate(variable = forcats::fct_reorder(variable, frequencies, .desc = TRUE)) 
+    #mutate(variable = forcats::fct_reorder(variable, frequencies, .desc = TRUE)) 
+    arrange(desc(frequencies)) %>% 
+    mutate(variable = factor(variable, levels = variable))
   
   if (only_na) {
     info_na <- info_na %>% 
@@ -211,8 +241,30 @@ plot_na_pareto <- function (x, only_na = FALSE, relative = FALSE, main = NULL, c
     return(info_na)
   }
   
-  ggplot(info_na, aes(x = variable)) +
-    geom_bar(aes(y = frequencies, fill = grade), stat = "identity") +
+  labels_grade <- paste0(names(grade),paste0("\n(<=", unlist(grade) * 100, "%)"))
+  n_pal <- length(labels_grade)
+  
+  if (n_pal <= 3) {
+    pals <- c("#FFEDA0", "#FEB24C", "#F03B20")
+  } else if (n_pal == 4) {
+    pals <- c("#FFFFB2", "#FECC5C", "#FD8D3C", "#E31A1C")
+  } else if (n_pal == 5) {
+    pals <- c("#FFFFB2", "#FECC5C", "#FD8D3C", "#F03B20", "#BD0026")
+  } else if (n_pal == 6) {
+    pals <- c("#FFFFB2", "#FED976", "#FEB24C", "#FD8D3C", "#F03B20", "#BD0026")
+  } else if (n_pal == 7) {    
+    pals <- c("#FFFFB2", "#FED976", "#FEB24C", "#FD8D3C", "#FC4E2A", "#E31A1C", 
+              "#B10026")
+  } else if (n_pal == 8) {
+    pals <- c("#FFFFCC", "#FFEDA0", "#FED976", "#FEB24C", "#FD8D3C", "#FC4E2A", 
+              "#E31A1C", "#B10026")
+  } else if (n_pal >= 9) {
+    pals <- c("#FFFFCC", "#FFEDA0", "#FED976", "#FEB24C", "#FD8D3C", "#FC4E2A", 
+              "#E31A1C", "#BD0026", "#800026")
+  }  
+  
+  p <- ggplot(info_na, aes(x = variable)) +
+    geom_bar(aes(y = frequencies, fill = grade), color = "darkgray", stat = "identity") +
     geom_text(aes(y = frequencies, 
                   label = paste(round(ratio * 100, 1), "%")),
               position = position_dodge(width = 0.9), vjust = -0.25) + 
@@ -223,7 +275,22 @@ plot_na_pareto <- function (x, only_na = FALSE, relative = FALSE, main = NULL, c
     scale_y_continuous(sec.axis = sec_axis(~.*scaleRight, name = "Cumulative (%)")) +
     labs(title = main, x = xlab, y = ylab) + 
     theme(axis.text.x = element_text(angle = 45, vjust = 1, hjust = 1),
-          legend.position = "top")
+          legend.position = "top") +
+    scale_fill_manual(values = pals, 
+                      drop = FALSE,
+                      name = "Missing Grade", 
+                      labels = labels_grade)
+  
+  if (typographic) {
+    p <- p +
+      theme_typographic() +
+      theme(legend.position = "top",
+            axis.title.x = element_text(size = 12),
+            axis.title.y = element_text(size = 12),
+            axis.title.y.right = element_text(size = 12))
+  }
+  
+  suppressWarnings(p)
 }
 
 
@@ -251,6 +318,8 @@ plot_na_pareto <- function (x, only_na = FALSE, relative = FALSE, main = NULL, c
 #' If this value is greater than the number of variables containing missing values, 
 #' all variables containing missing values are visualized. Variables containing many missing values are chosen first.
 #' @param main character. Main title.
+#' @param typographic logical. Whether to apply focuses on typographic elements to ggplot2 visualization. 
+#' The default is TRUE. if TRUE provides a base theme that focuses on typographic elements using hrbrthemes package.
 #' @examples
 #' # Generate data for the example
 #' carseats <- ISLR::Carseats
@@ -263,6 +332,11 @@ plot_na_pareto <- function (x, only_na = FALSE, relative = FALSE, main = NULL, c
 #' # Diagnose the data with missing_count using diagnose() function
 #' library(dplyr)
 #' 
+#' if (!requireNamespace("mice", quietly = TRUE)) {
+#'   stop("Package \"mice\" needed for this function to work. Please install it.",
+#'   call. = FALSE)
+#' }
+#' 
 #' mice::boys %>% 
 #'   diagnose %>% 
 #'   arrange(desc(missing_count))
@@ -279,16 +353,19 @@ plot_na_pareto <- function (x, only_na = FALSE, relative = FALSE, main = NULL, c
 #' # Using n_intersacts argument
 #' plot_na_intersect(mice::boys, only_na = FALSE, n_intersacts = 7)
 #' 
+#' # Not allow typographic elements
+#' plot_na_intersect(mice::boys, typographic = FALSE)
+#' 
 #' @importFrom purrr map_int
 #' @importFrom tibble enframe
 #' @importFrom gridExtra grid.arrange
-#' @importFrom reshape2 melt
 #' @importFrom utils head
 #' @import ggplot2
+#' @import hrbrthemes
 #' @import dplyr
 #' @export
 plot_na_intersect <- function (x, only_na = TRUE, n_intersacts = NULL, 
-                               n_vars = NULL, main = NULL)
+                               n_vars = NULL, main = NULL, typographic = TRUE)
 {
   N <- nrow(x)
   
@@ -346,7 +423,7 @@ plot_na_intersect <- function (x, only_na = TRUE, n_intersacts = NULL,
     }  
   }
   
-  dframe <- reshape2::melt(t(x)) %>% 
+  dframe <- get_melt(x) %>% 
     filter(value > 0) %>% 
     filter(!Var1 %in% c("n")) %>% 
     mutate(Var1 = as.numeric(Var1))
@@ -374,24 +451,12 @@ plot_na_intersect <- function (x, only_na = TRUE, n_intersacts = NULL,
     scale_y_continuous(breaks = seq(nrow(marginal_obs)), 
                        labels = marginal_obs$Var2,
                        limits = c(0, nrow(marginal_obs)) + 0.5) +    
-    xlab("Variables") +
-    theme(axis.text.x = element_text(angle = 45, vjust = 1, hjust = 1,
-                                     family = "mono"),
-          axis.title.y = element_blank(), axis.text.y = element_blank(),
-          axis.ticks.y = element_blank(),
-          legend.position = "none")
+    xlab("Variables")
   
   # Create plot of top
   top <- ggplot(marginal_var, aes(x = Var1, y = n_var)) +
-    geom_col(fill = "#F8766D") +
-    scale_y_continuous(position = "right") + 
-    scale_x_continuous(breaks = seq(marginal_var$Var1), 
-                       labels = marginal_var$n_var,
-                       limits = c(0, length(na_variable)) + 0.5) +
-    ylab("Frequency") +
-    theme(axis.ticks.x = element_blank(), axis.title.x = element_blank(),
-          axis.title.y = element_blank(), axis.text.y = element_blank(),
-          axis.ticks.y = element_blank())
+    geom_col(fill = "#69b3a2", color = "darkgray") +
+    ylab("Frequency")
   
   # for display the axis label
   max_char <- max(nchar(na_variable))
@@ -401,19 +466,9 @@ plot_na_intersect <- function (x, only_na = TRUE, n_intersacts = NULL,
   
   # Create plot of right
   right <- ggplot(marginal_obs, aes(x = Var2, y = n_obs)) +
-    geom_col(fill = flag) +
+    geom_col(fill = "#69b3a2", color = "darkgray") +
     coord_flip() +
-    scale_x_continuous(breaks = seq(marginal_obs$Var2), 
-                       labels = marginal_obs$n_obs,
-                       limits = c(0, nrow(marginal_obs)) + 0.5) +    
-    scale_y_continuous(breaks = breaks, 
-                       labels = breaks_label,
-                       limits = range(c(0, breaks))) +    
-    ylab("Frequency") +
-    theme(axis.text.x = element_text(angle = 45, vjust = 1, hjust = 1, 
-                                     family = "mono"),
-          axis.ticks.y = element_blank(), axis.title.y = element_blank(),
-          legend.position = "none")
+    ylab("Frequency")
   
   legend_txt <- paste(c("#Missing Vars:", "#Missing Obs:", "#Complete Obs:"), 
                       c(N_var_na, N_na, N_complete))
@@ -422,7 +477,7 @@ plot_na_intersect <- function (x, only_na = TRUE, n_intersacts = NULL,
   
   # Create information plot
   blank <- ggplot(data = legend_df, aes(x, y, label = txt)) + 
-    geom_label(fill = c("#00BFC4", "#F8766D", "#F8766D"), colour = "white", 
+    geom_label(fill = c("steelblue", "#F8766D", "#F8766D"), colour = "white", 
                fontface = "bold", size = 3, hjust = 0) + 
     xlim(c(0, 1)) +
     ylim(c(0, 0.6)) +
@@ -440,7 +495,79 @@ plot_na_intersect <- function (x, only_na = TRUE, n_intersacts = NULL,
           axis.line = element_blank()
     )
   
-  gridExtra::grid.arrange(top, blank, body, right,
-               ncol = 2, nrow = 2, widths = c(8, 2), heights = c(1, 5),
-               top = main)
-}  
+  if (typographic) {
+    top <- top +
+      theme_typographic() +
+      scale_x_continuous(breaks = seq(marginal_var$Var1), 
+                         labels = marginal_var$n_var,
+                         limits = c(0, length(na_variable)) + 0.5) +
+      scale_y_continuous(position = "left") + 
+      theme(axis.title.x = element_blank(),
+            axis.title.y = element_blank(),
+            axis.text.y = element_blank(),
+            plot.margin = margin(10, 10, 0, 10))
+    
+    body <- body +
+      theme_typographic() +
+      theme(legend.position = "none",
+            axis.title.x = element_text(size = 12),
+            axis.title.y = element_blank(),
+            axis.text.y = element_blank(),
+            plot.margin = margin(0, 10, 30, 10))
+      
+    right <- right +
+      theme_typographic() +
+      scale_x_continuous(breaks = seq(marginal_obs$Var2), 
+                         labels = marginal_obs$n_obs,
+                         limits = c(0, nrow(marginal_obs)) + 0.5) +    
+      scale_y_continuous(breaks = breaks, 
+                         labels = breaks_label,
+                         limits = range(c(0, breaks))) +    
+      theme(axis.title.y = element_blank(),
+            axis.title.x = element_text(color = "transparent"),
+            axis.text.x = element_text(color = "transparent"),
+            plot.margin = margin(0, 10, 30, 0))
+    
+    fontfamily <- get_font_family()
+    
+    main <- grid::textGrob(main, gp = grid::gpar(fontfamily = fontfamily, 
+                                                 fontsize = 18, font = 2),
+                          x = unit(0.075, "npc"), just = "left")
+    
+  } else {
+    body <- body +
+      theme(axis.text.x = element_text(angle = 45, vjust = 1, hjust = 1,
+                                       family = "mono"),
+            axis.title.y = element_blank(), axis.text.y = element_blank(),
+            axis.ticks.y = element_blank(),
+            legend.position = "none")
+    
+    top <- top +
+      scale_y_continuous(position = "right") + 
+      scale_x_continuous(breaks = seq(marginal_var$Var1), 
+                         labels = marginal_var$n_var,
+                         limits = c(0, length(na_variable)) + 0.5) +
+      theme(axis.ticks.x = element_blank(), axis.title.x = element_blank(),
+            axis.title.y = element_blank(), axis.text.y = element_blank(),
+            axis.ticks.y = element_blank())
+      
+    right <- right +
+      scale_x_continuous(breaks = seq(marginal_obs$Var2), 
+                         labels = marginal_obs$n_obs,
+                         limits = c(0, nrow(marginal_obs)) + 0.5) +    
+      scale_y_continuous(breaks = breaks, 
+                         labels = breaks_label,
+                         limits = range(c(0, breaks))) +    
+      theme(axis.text.x = element_text(angle = 45, vjust = 1, hjust = 1, 
+                                       family = "mono", color = "transparent"),
+            axis.ticks.x = element_blank(),
+            axis.ticks.y = element_blank(), 
+            axis.title.y = element_blank(),
+            legend.position = "none",
+            axis.title.x = element_text(color = "transparent"))
+  }
+  
+  suppressWarnings(gridExtra::grid.arrange(top, blank, body, right,
+               ncol = 2, nrow = 2, widths = c(9, 2), heights = c(1, 5),
+               top = main))
+} 
