@@ -113,9 +113,9 @@ head(Advertising_log)
 # summary of transformation
 summary(Advertising_log)
 # viz of transformation
-plot(Advertising_log)
+# plot(Advertising_log)
 
-## ----binning, fig.width = 6, fig.height = 5-----------------------------------
+## ----binning, fig.width = 8, fig.height = 6-----------------------------------
 # Binning the carat variable. default type argument is "quantile"
 bin <- binning(carseats$Income)
 # Print bins class object
@@ -134,34 +134,44 @@ binning(carseats$Income, nbins = 5, type = "pretty")
 binning(carseats$Income, nbins = 5, type = "kmeans")
 binning(carseats$Income, nbins = 5, type = "bclust")
 
+# Extract the binned results
+extract(bin)
+
 # -------------------------
 # Using pipes & dplyr
 # -------------------------
 library(dplyr)
 
 carseats %>%
- mutate(Income_bin = binning(carseats$Income)) %>%
+ mutate(Income_bin = binning(carseats$Income) %>% 
+                     extract()) %>%
  group_by(ShelveLoc, Income_bin) %>%
  summarise(freq = n()) %>%
  arrange(desc(freq)) %>%
  head(10)
 
-## ----binning_by, fig.width = 6, fig.height = 5--------------------------------
-# optimal binning
+## ----binning_by, fig.width = 8, fig.height = 5, dpi=300-----------------------
+library(dplyr)
+
+# optimal binning using character
 bin <- binning_by(carseats, "US", "Advertising")
+
+# optimal binning using name
+bin <- binning_by(carseats, US, Advertising)
 bin
 
 # summary optimal_bins class
 summary(bin)
 
-# information value 
-attr(bin, "iv")
-
-# information value table
-attr(bin, "ivtable")
+# performance table
+attr(bin, "performance")
 
 # visualize optimal_bins class
-plot(bin, sub = "bins of Advertising variable")
+plot(bin)
+
+# extract binned results
+extract(bin) %>% 
+  head(20)
 
 ## ----trans_report, eval=FALSE-------------------------------------------------
 #  carseats %>%
@@ -172,21 +182,18 @@ plot(bin, sub = "bins of Advertising variable")
 #    transformation_report(target = US, output_format = "html",
 #      output_file = "transformation_carseats.html")
 
-## ----trans_title_pdf, echo=FALSE, out.width='70%', fig.align='center', fig.pos="!h", fig.cap="Data transformation report cover"----
+## ----trans_title_pdf, echo=FALSE, out.width='60%', fig.align='center', fig.pos="!h", fig.cap="Data transformation report cover"----
 knitr::include_graphics('img/trans_title_pdf.png')
 
-## ----trans_agenda_pdf, echo=FALSE, out.width='70%', fig.align='center', fig.pos="!h", fig.cap="Table of Contents"----
+## ----trans_agenda_pdf, echo=FALSE, out.width='60%', fig.align='center', fig.pos="!h", fig.cap="Table of Contents"----
 knitr::include_graphics('img/trans_agenda_pdf.png')
 
-## ----trans_content_pdf, echo=FALSE, out.width='70%', fig.align='center', fig.pos="!h", fig.cap="Data Transformation Report Table and Visualization Example"----
+## ----trans_content_pdf, echo=FALSE, out.width='60%', fig.align='center', fig.pos="!h", fig.cap="Data Transformation Report Table and Visualization Example"----
 knitr::include_graphics('img/trans_content_pdf.png')
 
-## ----trans_agenda_html, echo=FALSE, out.width='80%', fig.align='center', fig.pos="!h", fig.cap="Data transformation report titles and table of contents"----
+## ----trans_agenda_html, echo=FALSE, out.width='60%', fig.align='center', fig.pos="!h", fig.cap="Data transformation report titles and table of contents"----
 knitr::include_graphics('img/trans_agenda_html.png')
 
-## ----trans_table_html, echo=FALSE, out.width='50%', fig.align='center', fig.pos="!h", fig.cap="Report table example (web)"----
-knitr::include_graphics('img/trans_table_html.png')
-
-## ----trans_viz_html, echo=FALSE, out.width='75%', fig.align='center', fig.pos="!h", fig.cap="Data transformation report Binning information (web)"----
-knitr::include_graphics('img/trans_viz_html.png')
+## ----trans_table_html, echo=FALSE, eval=FALSE, out.width='50%', fig.align='center', fig.pos="!h", fig.cap="Report table example (web)"----
+#  knitr::include_graphics('img/trans_table_html.png')
 
